summaryrefslogtreecommitdiffstats
path: root/extensions/common/extension_messages.h
diff options
context:
space:
mode:
authorhanxi <hanxi@chromium.org>2015-03-11 16:40:06 -0700
committerCommit bot <commit-bot@chromium.org>2015-03-11 23:41:10 +0000
commit3df97b200b7105e90e59703b3ee6d42581a3d125 (patch)
tree70fbeb5f800c76a3da4e6c7170f47969091c7b5d /extensions/common/extension_messages.h
parentb54d1475fa0d4e998b3261164339a6d32e5a1c8e (diff)
downloadchromium_src-3df97b200b7105e90e59703b3ee6d42581a3d125.zip
chromium_src-3df97b200b7105e90e59703b3ee6d42581a3d125.tar.gz
chromium_src-3df97b200b7105e90e59703b3ee6d42581a3d125.tar.bz2
Refactoring: de-couple Extensions from "script injection System" [render side]:4
Replace extension_id with host_id to avoid extension-specific check on webUI. BUG=459234 Review URL: https://codereview.chromium.org/988633003 Cr-Commit-Position: refs/heads/master@{#320185}
Diffstat (limited to 'extensions/common/extension_messages.h')
-rw-r--r--extensions/common/extension_messages.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/extensions/common/extension_messages.h b/extensions/common/extension_messages.h
index 1cd55b6..73adbcd 100644
--- a/extensions/common/extension_messages.h
+++ b/extensions/common/extension_messages.h
@@ -450,16 +450,17 @@ IPC_MESSAGE_ROUTED1(ExtensionMsg_ExecuteCode,
// handle is valid in the context of the renderer.
// If |owner| is not empty, then the shared memory handle refers to |owner|'s
// programmatically-defined scripts. Otherwise, the handle refers to all
-// extensions' statically defined scripts.
-// If |changed_extensions| is not empty, only the extensions in that set will
-// be updated. Otherwise, all extensions that have scripts in the shared memory
-// region will be updated. Note that the empty set => all extensions case is not
+// hosts' statically defined scripts. So far, only extension-hosts support
+// statically defined scripts; WebUI-hosts don't.
+// If |changed_hosts| is not empty, only the host in that set will
+// be updated. Otherwise, all hosts that have scripts in the shared memory
+// region will be updated. Note that the empty set => all hosts case is not
// supported for per-extension programmatically-defined script regions; in such
// regions, the owner is expected to list itself as the only changed extension.
IPC_MESSAGE_CONTROL3(ExtensionMsg_UpdateUserScripts,
base::SharedMemoryHandle,
- extensions::ExtensionId /* owner */,
- std::set<std::string> /* changed extensions */)
+ HostID /* owner */,
+ std::set<HostID> /* changed hosts */)
// Trigger to execute declarative content script under browser control.
IPC_MESSAGE_ROUTED4(ExtensionMsg_ExecuteDeclarativeScript,
@@ -450,16 +450,17 @@ IPC_MESSAGE_ROUTED1(ExtensionMsg_ExecuteCode,
// supported for per-extension programmatically-defined script regions; in such
-// regions, the owner is expected to list itself as the only changed extension.
+// regions, the owner is expected to list itself as the only changed host.
IPC_MESSAGE_CONTROL3(ExtensionMsg_UpdateUserScripts,
base::SharedMemoryHandle,